# Chapter 10 of Introduction to Data Science for Business
#

oilChanges <- c(3,5,2,3,1,4,6,4,3,2,0,10,7,8)
repairs <- c(300, 300, 500, 400, 700, 420, 100, 290,
             475, 620, 600, 0, 200, 50)
miles <- c(20100, 23200, 19200, 22100, 18400, 23400, 
           17900, 19900, 20100, 24100, 18200, 19600, 20800, 
           19700)
oil <- data.frame(oilChanges, repairs, miles)
View(oil)

#plot the data two different ways
plot(oil$oilChanges, oil$repairs)

library(ggplot2)
ggplot(oil, aes(x=miles, y=repairs)) + geom_point()

#build a linear model
model1 <- lm(formula=repairs ~ oilChanges, data=oil)
summary(model1)

#explore the best fit line
plot(oil$oilChanges, oil$repairs)
abline(model1)


#build a  model based on both attributes
m <- lm(formula=repairs ~ oilChanges + miles, 
        data=oil)
summary(m)


#build a better model, with more data
oil$oilChangeCost <- oil$oilChanges * 350
oil$totalCost <- oil$oilChangeCost + oil$repairs
ggplot(oil, aes(x=oilChanges, y=totalCost)) + geom_point() +
  geom_smooth(method="lm")

m <- lm(formula=totalCost ~ oilChanges, data=oil)


#use the model to predict values
test = data.frame(oilChanges=0)
predict(m, test, type="response")

test = data.frame(oilChanges=5)
predict(m, test, type="response")

test = data.frame(oilChanges=10)
predict(m, test, type="response")



#install and library the caret package as needed
#install.packages("caret")
library(caret)

#create the model, letting caret’s train function
#call the ‘lm’ function
model1 <- train(repairs ~ oilChanges, data = oil,
                trControl=trainControl(method = "none"),
                method = "lm")
summary(model1)


#use the ‘set.seed’ to enable repeatable results
set.seed(10) 

# Make sure caret is loaded and ready
library(caret)

# Create our weather outcome variable
sunnyDays.percentCloudy <- 
  sample(1:10, 16, replace=TRUE)
cloudyDays.percentCloudy <- 
  sample(90:100, 12, replace=TRUE)
percentCloudyAllDays <- c(sunnyDays.percentCloudy, 
                          cloudyDays.percentCloudy)

# The p=0.5 splits the dataset in half 
trainList <- createDataPartition(percentCloudyAllDays,
                                 p=0.5, list=FALSE)

# Show the results
data.frame(trainIndex, 
           cloudPercent =percentCloudyAllDays [trainList])

#create train and test datasets
trainData <- percentCloudyAllDays[trainList,]
testData <- percentCloudyAllDays[-trainList,]

# makes the sampling predictable
set.seed(123)  

# Randomly sample for training dataset elements  
trainList <- createDataPartition(
  y=oil$repairs, p=.66, list=FALSE)

head(trainList[,1])

#create train and test datasets
trainData <- oil[trainList,]
testData <- oil[-trainList,]

lm.model <- train(repairs ~ oilChanges+miles, 
                  data = trainData, 
                  trControl=trainControl(method = "none"),
                  method = "lm")

summary(lm.model)

predictValues <- predict(lm.model, newdata=testData)
cor(predictValues, testData$repairs)^2


# Using k-fold cross valiation
trctrl <-   trainControl(method="repeatedcv", number=10, repeats=3)
lm.model1 <- train(repairs ~ oilChanges+miles, data = trainData,
                   method = "lm", 
                   trControl=trctrl)

summary(lm.model1)

predictValues <- predict(lm.model1, newdata=testData)
cor(predictValues, testData$repairs)^2


###########################
# case
###########################

#load survey 
library(tidyverse)
library(jsonlite) 
mydata.list <- fromJSON("completeSurvey.json" )
surveyWithNA <- data.frame(mydata.list)

#Remove rows with‘Likelihood.to.recommend’ == NA
survey <- surveyWithNA %>% 
  filter(!is.na(Likelihood.to.recommend))

#build a model
trctrl <-   trainControl(method="repeatedcv", 
                         number=10, repeats=3)
lmOut <- train(Likelihood.to.recommend ~ Type.of.Travel + 
              Airline.Status + Age, 
              data=survey,
              trControl=trctrl,
              method = "lm")

summary(lmOut)

#explore age

# First, recode Age to represent each decade
survey$roundedAge <- as.factor(round(survey$Age,-1))


# Now make a bar plot by decade group
survey %>%
  group_by(roundedAge) %>%
  summarize(ltr=mean(Likelihood.to.recommend)) %>%
  ggplot() + aes(x=roundedAge, y=ltr) + geom_col()

cor(survey$Likelihood.to.recommend, survey$Age)
cor(survey$Likelihood.to.recommend, survey$Age^2)


#########################################
# code to draw first chart in chapter 10
#########################################
plot(c(1,2,3,4,5),c(1.05,1.9,3.2,3.85,5.1), xlab="Predictor", ylab="Outcome")
abline(0,1)
