# Chapter 11 of Introduction to Data Science for Business
#

webSite <- "http://archive.ics.uci.edu/ml/"
dataLocation <- "machine-learning-databases"
adultData <- "/adult/adult.data"
theUrl <- paste0(webSite, dataLocation, adultData)
incomeDF <- read_csv(theUrl, col_names=FALSE)

col_names <- c("age", "workclass", "fnlwgt", 
               "education", "education_num",
               "marital_status", "occupation",  
               "relationship", "race", "sex",
               "capital_gain", "capital_loss",  
               "hours_per_week", "native_country",
               "income")
colnames(incomeDF) <- col_names

glimpse(incomeDF)

table(incomeDF$income)

#remove a column
library(dplyr)
incomeDF <- select(incomeDF, -fnlwgt)

#Update the columns to factor – if it’s a string
incomeDF <- mutate_if(incomeDF,is.character, factor)

#define levels for the factors
levels(incomeDF$workclass) <- list(
  public=c("Federal-gov","State-gov","Local-gov"),
  private=c("Private","Self-emp-not-inc",
            "Self-emp-inc"),
  other= c("Never-worked","Without-pay", "?"))
levels(incomeDF$education)<- list(
  noCollege=c("Preschool", "1st-4th",
              "5th-6th","7th-8th", "9th",
              "Assoc-acdm","Assoc-voc","10th",     
              "11th","12th", "HS-grad"), 
  graduate=c("Bachelors","Some-college"),
  master=c("Masters", "Prof-school"), 
  phd=c("Doctorate"))
levels(incomeDF$marital_status)<- list(
  divorce=c("Divorced","Separated"), 
  married=c("Married-AF-spouse",
            "Married-civ-spouse",
            "Married-spouse-absent"),
  notmarried=c("Never-married"), 
  widowed=c("Widowed"))
levels(incomeDF$occupation)<- list(
  clerical=c("Adm-clerical"), 
  tradeskill=c("Craft-repair",
               "Machine-op-inspct","Other-service"),
  physical = c("Transport-moving",
               "Priv-house-serv","Protective-serv", 
               "Handlers-cleaners"),
  highskill=c("Sales","Tech-support","Armed-Forces", 
              "Prof-specialty","Exec-managerial"),
  agricultr=c("Farming-fishing"), 
  unknown = c("?"))
levels(incomeDF$native_country)<- list(  
  Asia=c("Vietnam","Laos","Cambodia","Thailand", 
         "Japan", "South", "China","India","Hong", 
         "Iran", "Philippines", "Taiwan"),
  NorthAmerica=c("Canada","Cuba",
                 "Dominican-Republic","Guatemala","Haiti", 
                 "Honduras","Jamaica","Mexico","Nicaragua",
                 "Puerto-Rico","El-Salvador","United-States",
                 "Outlying-US(Guam-USVI-etc)"),  
  SouthAmerica=c("Ecuador","Peru","Columbia", 
                 "Trinadad&Tobago"),     
  Europe=c("England","France","Germany","Greece",
           "Holand-Netherlands","Italy","Hungary",
           "Ireland", "Poland","Portugal","Scotland", 
           "Yugoslavia"),
  unknown = c("?"))

#install.packages("caret")
library(caret)

# makes the sampling predictable
set.seed(111)  

# Randomly sample for training dataset elements  
trainList <- createDataPartition(
  y=incomeDF$income,p=.70, list=FALSE)

#create train and test datasets
trainData <- incomeDF [trainList,]
testData <- incomeDF [-trainList,]

#build first SVM model
svm.model <- train(income ~ ., data = trainData, 
                   method = "svmRadial", 
                   trControl=trainControl(method = "none"),
                   preProcess = c("center", "scale"))
svm.model

#use the model on the test data
predictValues <- predict(svm.model, newdata=testData)
confusionMatrix(predictValues, testData$income)               

#use a smaller training dataset
set.seed(111) 
subsetList <- createDataPartition(
  y= incomeDF$income,p=.05, list=FALSE)
trainData <- incomeDF[subsetList,]
testData <- incomeDF[-subsetList,]

svm.model <- train(income ~ ., data = trainData, 
                   method = "svmRadial", 
                   trControl=trainControl(method = "none"),
                   preProcess = c("center", "scale"))  

predictValues <- predict(svm.model, newdata=testData)
confusionMatrix(predictValues, testData$income)               

#now try cross validation
# Set up the same data as for the 1st example
set.seed(111)
# Create the test and train dataset
trainList <- createDataPartition(
  y=incomeDF$income,p=.70, list=FALSE)
trainData <- incomeDF [trainList,]
testData <- incomeDF [-trainList,]

# Generate the SVM model
trctrl <- trainControl(method = "repeatedcv", 
                       number = 10, repeats = 3)
svm.model.kfold <- train(income ~ ., 
                         data = trainData, 
                         method = "svmRadial",
                         trControl=trctrl,
                         preProcess = c("center", "scale"))
model.svm.kfold

predictValues <- predict(svm.model.kfold, 
                         newdata = testData )
confusionMatrix(predictValues, testData$income)              

#look at support vectors
svm.model.kfold$finalModel@nSV
hist(svm.model.kfold$finalModel@alpha[[1]], 
     main="Histogram of Alpha")




#build partition trees
model.rpart <- train(income ~ ., method = "rpart", 
                     data = trainData, 
                     tuneLength = 50)
model.rpart

predictValues <- predict(model.rpart, 
                         newdata=testData)
confusionMatrix(predictValues, testData$income)   

library(rpart.plot)
rpart.plot(model.rpart$finalModel)
varImp(model.rpart)


#try a simplier model
trainData <- dplyr::select(trainData, -sex, -age, -race)
rpart.model.new <- train(income ~ ., 
                         method = "rpart", 
                         data = trainData, tuneLength = 50)
predictValues <- predict(rpart.model.new, 
                         newdata = testData )
cm <-confusionMatrix(predictValues, testData$income)
cm$overall[1]



###########################
# case
###########################
 
#load survey 
library(jsonlite) 
mydata.list <- fromJSON("completeSurvey.json" )
surveyWithNA <- data.frame(mydata.list)

#Remove rows with‘Likelihood.to.recommend’ == NA
survey <- surveyWithNA %>% 
  filter(!is.na(Likelihood.to.recommend))

#predict who will be a detractor
survey$Detractor <- 
  as.factor(survey$Likelihood.to.recommend < 7)

#make sure we can reproduce our results
set.seed(123)

# create train and test dataset 
trainList <- createDataPartition(y=survey$Detractor,
                                 p=.05,list=FALSE)
trainSet <- survey[trainList,]
testSet <- survey[-trainList,]

#Build an SVM model, predicting who will be a detractor
trctrl <- trainControl(method = "cv", number = 10)
svmModel <- train(Detractor ~
                    Eating.and.Drinking.at.Airport +
                    Age +
                    Airline.Status +
                  Type.of.Travel,
                  data=trainSet,
                  method="svmRadial",
                  preProc=c("center","scale"),
                  trControl=trctrl)
svmModel

predOut <- predict(svmModel,newdata=testSet)
confusionMatrix(predOut, testSet$Detractor)

svmModel1 <- train(Detractor ~ 
                     Airline.Status+Type.of.Travel, data=trainSet, 
                   method="svmRadial", preProc=c("center","scale"),
                   trControl=trctrl)

#Assess Fit with new data
predOut <- predict(svmModel1,newdata=testSet)
confusionMatrix(predOut, testSet$Detractor) 


#try partition trees
library(rpart)
cartTree.model <- train(Detractor ~ 
                          Eating.and.Drinking.at.Airport+roundedAge+
                          Airline.Status+Type.of.Travel, 
                        data=trainSet,  method="rpart", tuneLength=10,
                        trControl=trctrl)

predOut <- predict(cartTree.model,newdata=testSet)
confusionMatrix(predOut, testSet$Detractor) 

varImp(cartTree.model)

#try a simplier model
cartTree.model1 <- train(Detractor ~ 
                           Airline.Status+Type.of.Travel, 
                         data=trainSet,  method="rpart", tuneLength=10,
                         trControl=trctrl)
 
predOut <- predict(cartTree.model,newdata=testSet)
confusionMatrix(predOut, testSet$Detractor) 

library(rpart.plot)
rpart.plot(cartTree.model1$finalModel)
