# Chapter 12 of Introduction to Data Science for Business
#

#install.packages("arules")
library(arules)

data(Groceries)

summary(Groceries)
 
#view frequent items
itemFrequencyPlot(Groceries, support=0.1)
itemFrequencyPlot(Groceries, support=0.05, cex.names=0.5)

#look at a different dataset
data(AdultUCI)
AdultUCI.t <- AdultUCI
AdultUCI.t$age <- as.factor(AdultUCI.t$age)
AdultUCI.t$fnlwgt <- as.factor(AdultUCI.t$fnlwgt)
AdultUCI.t$'education-num' <- 
  as.factor(AdultUCI.t$'education-num')
AdultUCI.t$'capital-gain' <-   
  as.factor(AdultUCI.t$'capital-gain')
AdultUCI.t$'capital-loss' <- 
  as.factor(AdultUCI.t$'capital-loss')
AdultUCI.t$'hours-per-week' <- 
  as.factor(AdultUCI.t$'hours-per-week')
AdultUCI.trans <- as(AdultUCI.t, "transactions")

itemFrequencyPlot(AdultUCI.trans, support=0.2, 
                  cex.names=1.1)


#build rules
apriori(Groceries,parameter=list(support=0.005,  
                                 confidence=0.5))
ruleset <- apriori(Groceries,
                parameter = list(support = 0.01,confidence = 0.5))
summary(ruleset)
inspect(ruleset)


#visualize the rules
#install.packages("arulesViz")
library(arulesViz)

ruleset <- apriori(Groceries,
                   parameter=list(support=0.005, confidence=0.35))
plot(ruleset)

goodrules <- ruleset[quality(ruleset)$lift > 3.5]
inspect(goodrules)

###########################
# case
###########################
#load survey 
library(jsonlite) 
mydata.list <- fromJSON("completeSurvey.json" )
surveyWithNA <- data.frame(mydata.list)

#Remove rows with‘Likelihood.to.recommend’ == NA
survey <- surveyWithNA %>% 
  filter(!is.na(Likelihood.to.recommend))

#look for detractor rules
Detractor <- as.factor(survey$Likelihood.to.recommend <7)

#Define several attributes as factors
Age <- as.factor(round(survey$Age, digits=-1))
Price.Sensitivity <- as.factor(survey$Price.Sensitivity)
Shopping.Amount.at.Airport <-   
  as.factor(round(survey$Shopping.Amount.at.Airport, 
                  digits=-2))
Class <- survey$Class
Type.of.Travel <- survey$Type.of.Travel
Airline.Status <- survey$Airline.Status
Gender <- survey$Gender
Origin.state <- survey$Origin.State

rSurvey <- data.frame(Detractor, Age, Price.Sensitivity,  
                      Shopping.Amount.at.Airport,
                      Class, Type.of.Travel, 
                      Airline.Status, Gender, Origin.state)
rSurvey.trans <- as(rSurvey, "transactions") 

#make sure we have access to the functions
library(arules)
library(arulesViz)

#Explore item frequency
itemFrequencyPlot(rSurvey.trans, support=0.1, 
                  cex.names=0.7)

#generate rules
ruleset <- apriori(rSurvey.trans, 
                   parameter=list(supp=0.1, conf=0.6), 
                   appearance = 
                     list(default="lhs",  
                          rhs=("Detractor=TRUE")))
ruleset

inspect(ruleset)
inspect(ruleset[c(1,4)])
plot(ruleset)

