# Chapter 14 of Introduction to Data Science for Business
#
# In chapter 14, we need separate files for each version
# of the app that the chapter describes.
#
# This is the first app: The default app that RStudio 
# creates when you ask for a new Shiny app.

library(shiny)

# Define UI for application that draws a histogram
ui <- fluidPage(
  
  # Application title
  titlePanel("Old Faithful Geyser Data"),
  
  # Sidebar with a slider input for number of bins 
  sidebarLayout(
    sidebarPanel(
      sliderInput("bins",
                  "Number of bins:",
                  min = 1,
                  max = 50,
                  value = 30)
    ),
    
    # Show a plot of the generated distribution
    mainPanel(
      plotOutput("distPlot")
    )
  )
)

# Define server logic required to draw a histogram
server <- function(input, output) {   
  output$distPlot <- renderPlot({
    # generate bins based on input$bins from ui.R
    x    <- faithful[, 2] 
    bins <- seq(min(x), max(x), length.out = 
                  input$bins + 1)
    
    # draw the histogram with the specified number  
    # of bins
    hist(x, breaks = bins, col = 'darkgray', border 
         = 'white')
  })
}

# Run the application 
shinyApp(ui = ui, server = server)


