# Chapter 14 of Introduction to Data Science for Business
#
# In chapter 14, we need separate files for each version
# of the app that the chapter describes.
#
# This is the third app

library(shiny)
library(ggmap)
library(ggplot2)

#new library
library(tidyverse)

ui <- fluidPage(
  selectInput("variable", "Variable:",
              c("july population" = "july11pop",
                "region of country" = "region",                
                "change in population" = "popChange",
                "Percent change in population" =  
                  "percentChange")),
  plotOutput("plot")
)

server <- function(input, output) {
  dfStates <- readCensus()
  dfStates <- dfStates[dfStates$stateName != 
                         "District of Columbia", ]
  
  dfStates$region <- state.region
  dfStates$stateName <- 
    tolower(dfStates$stateName)
  
  dfStates$popChange <- dfStates$july11pop - 
    dfStates$july10pop
  dfStates$percentChange <- 
    dfStates$popChange/dfStates$july10pop * 100
  
  us <- map_data("state")
  
  output$plot <- renderPlot(
#    ggplot(dfStates, aes(map_id = state))  +
    ggplot(dfStates, aes(map_id = stateName))  +
      geom_map(map = us,  
               aes(fill=dfStates[,input$variable])) +
      expand_limits(x = us$long, y = us$lat) +
      coord_map() + ggtitle("state population") + 
      guides(fill=guide_legend(title=input$variable))
  )
}

# Numberize() - Gets rid of commas and other junk and 
# converts to numbers
# Assumes that the inputVector is a list of data that 
# can be treated as character strings
Numberize <- function(inputVector)
{
  # Get rid of commas and spaces
  inputVector<-str_replace_all(inputVector, "[, ]","")
  
  #convert to a number and then return that number
  return(as.numeric(inputVector))
}

#read in the census data set. This function
#is the same as the one previously defined
readCensus <- function() {
  
  u1 <- "http://www2.census.gov/programs-surveys/" 
  u2 <- "popest/tables/2010-2011/state/totals/"
  u3 <-    "nst-est2011-01.csv"
  urlToRead <- paste0(u1, u2, u3)
  
  
  #do the basic cleanup
  testFrame <- read.csv(url(urlToRead))
  testFrame<-testFrame[-1:-8,] 
  testFrame<-testFrame[,1:5]
  testFrame$stateName <- testFrame[,1]
  testFrame<-testFrame[,-1]
  testFrame<-testFrame[-52:-58,]
  
  #remove the ‘dot’ from the state name
  testFrame$stateName <- gsub("\\.","", 
                              testFrame$stateName)
  
  #convert columns to numbers and rename columns
  testFrame$april10census <-Numberize(testFrame$X)
  testFrame$april10base <-Numberize(testFrame$X.1)
  testFrame$july10pop <-Numberize(testFrame$X.2)
  testFrame$july11pop <-Numberize(testFrame$X.3)
  testFrame <- testFrame[,-1:-4]
  
  #remove the old rownames, which are now confusing
  rownames(testFrame) <- NULL
  
  return(testFrame)
}



# Run the application 
shinyApp(ui = ui, server = server)

