# Chapter 3 of Introduction to Data Science for Business
#

# install.packages only has to be done once
install.packages("readr")
library(readr)
urlToRead <-
  "http://www2.census.gov/programs-surveys/popest/tables/2010-2011/state/totals/nst-est2011-01.csv"

testFrame <- read_csv(url(urlToRead))
str(testFrame)

#removing rows and columns
testFrame <- testFrame[-1:-8,]

summary(testFrame[,6:10]) 

testFrame <- testFrame[,1:5]

tail(testFrame,5)

testFrame <- testFrame[-54:-58,]

testFrame <- testFrame[complete.cases(testFrame), ]

#renaming rows and columns
colnames(testFrame)

cnames <- c("Region","Census","Estimate","April2010","April2011")
colnames(testFrame) <- cnames
colnames(testFrame)

#cleaning up the elements
testFrame$Region <- gsub("\\.","", testFrame$Region)

testFrame$Census <- as.numeric(gsub(",", "", testFrame$Census))
testFrame$Estimate <- as.numeric(gsub(",", "", testFrame$Estimate))
testFrame$April2010 <- as.numeric(gsub(",", "", testFrame$April2010))

str(testFrame)

head(testFrame,5)

#sorting and subsetting
testFrame$Change <- testFrame$April2011 - testFrame$April2010
avgChange <- mean(testFrame$Change)

testFrame[testFrame$Change > avgChange, ]

growingStates <- testFrame[testFrame$Change > avgChange, ]
growingStates <- growingStates[order(growingStates$Change), ]
head(growingStates, 5)

growingStates <- growingStates[order(growingStates$Change, decreasing = TRUE), ]
head(growingStates, 5)

#install only needs to be done once
install.packages("tidyverse")

library(tidyverse)

#sorting and subsetting using tidyvers
testFrame <- mutate(testFrame, Change = (April2011 - April2010))
avgChange <- mean( pull(testFrame, Change))
growingStates <- filter(testFrame, Change > avgChange)
growingStates <- arrange(growingStates, desc(Change))
growingStates <- slice(growingStates, 1:5)
select(growingStates, Region, April2011, Change)

testFrame %>%
  mutate(Change=(April2011 - April2010)) %>%
  filter(Change>mean(Change)) %>%
  arrange(desc(Change)) %>%
  slice(1:5) %>%
  select(Region, April2011, Change)

testFrame %>%
  mutate(Change=(April2011 - April2010)) %>%
  filter(Change>mean(Change)) %>%
  arrange(desc(Change)) %>%
  slice(1:5) %>%
  select(Region, April2011, Change) -> growingStates


##########################
# case study
##########################
library(readr)
smallSurvey <- read_csv("smallSurvey.csv")

#Explore the small survey using str
str(smallSurvey)

# Next, try glimpse()
#What is the average Likelihood.to.recommend?
glimpse(smallSurvey)
mean(smallSurvey$LTR)

#Remove NAs from the LTR column
smallSurvey <- filter(smallSurvey, !is.na(LTR))

#What is the average Likelihood.to.recommend?
mean(smallSurvey$LTR)

#The mean Likelihood.to.recommend by Type.of.Travel 
smallSurvey %>%
  group_by(Type.of.Travel) %>%
  summarize(mean=mean(LTR), count=n()) 

#What is the average Likelihood.to.recommend by Age?
# Round Age by decades,then sort the new dataframe
smallSurvey %>%
  mutate(Age, Age=round(Age, digits=-1)) %>%
  group_by(Age) %>%
  summarize(mean=mean(LTR), count=n()) %>%
  arrange(desc(mean))


