# Chapter 5 of Introduction to Data Science for Business
#

myFamilyAges <- c(43, 42, 12, 8, 5)
mean(myFamilyAges)

#code for creating Table 5.1
myFamilyNames <- c("Dad","Mom","Sis","Bro","Dog")
table9_1 <- data.frame(Who=myFamilyNames,
                       Age=myFamilyAges,
                       Age_Mean=myFamilyAges-mean(myFamilyAges),
                       Age_Mean_Sq=(myFamilyAges-mean(myFamilyAges))^2)
table9_1
sum(table9_1$Age_Mean_Sq)
sum(table9_1$Age_Mean_Sq)/4

var(myFamilyAges)
sd(myFamilyAges)

#Using Descriptive Statistics

#read in the census data set
readCensus <- function(urlToRead) {
  
  #read the data from the web
  #testFrame <- read_csv(url(urlToRead))
  testFrame <- read_csv(urlToRead)
  
  #use pipes to keep updating testFrame
  testFrame <- testFrame %>%
    
    #only keep the first 5 columns
    select(1:5) %>%
    
    #convert columns to numbers & rename columns
    mutate(april10census=Numberize(testFrame$X2))%>%
    mutate(april10base=Numberize(testFrame$X3)) %>%
    mutate(july10pop=Numberize(testFrame$X4)) %>%
    mutate(july11pop=Numberize(testFrame$X5)) %>%
    
    #remove the old columns that have been updated
    select( -X2, -X3, -X4, -X5) %>%
    
    #remove the first 8 rows (‘header information’)
    slice(-1:-8) %>%
    
    #rename the first column to StateName
    rename(stateName=1) %>%
    
    #remove the last rows (tail info to see)
    slice(c(-52, -54:-n())) %>%
    
    #remove the ‘dot’ from the state name
    mutate(stateName=
             str_replace_all(stateName, "\\.","")) 
  
  #remove the old rownames, which are now confusing
  rownames(testFrame) <- NULL
  
  return(testFrame)
}

# Numberize() - Gets rid of commas and other junk and 
# converts to numbers
# Assumes that the inputVector is a list of data that 
# can be treated as character strings
Numberize <- function(inputVector)
{
  # Get rid of commas and spaces
  inputVector<-str_replace_all(inputVector, "[, ]","")
  
  #convert to a number and then return that number
  return(as.numeric(inputVector))
}

library(tidyverse)
USregionPops <- readCensus(      
  "http://www2.census.gov/programs-surveys/popest/tables/2010-2011/state/totals/nst-est2011-01.csv")

USregionPops$april10census[1:3]

mean(USregionPops$april10census)
median(USregionPops$april10census)
mode(USregionPops$april10census)
var(USregionPops$april10census)
sd(USregionPops$april10census)


#using histrograms
hist(USregionPops$april10census)

hist(USregionPops$april10census, breaks=20)

USregionPops[which.max(USregionPops$july11pop),]

#normal distributions
hist(rnorm(52, 6043834, 6764460))

##########################
# case study
##########################
library(tidyverse)

smallSurvey <- read_csv("smallSurvey.csv")

#remove the NAs from the LTR column
smallSurvey <- filter(smallSurvey, !is.na(LTR))

#get the LTR for all business travels, using core R
bTrue <- smallSurvey$Type.of.Travel=="Business travel"
busTravel <- smallSurvey$LTR[bTrue]

#get the LTR for all personal travel, using tidyverse
perTravel <- smallSurvey %>% 
  filter( Type.of.Travel=="Personal Travel") %>%
  pull(LTR)

#define two colors, including transparency (alpha)
myBlue <- rgb(red=0, green=0, blue=0.75, alpha=.75)
myGreen <- rgb(red=0, green=0.75, blue=0, alpha=.75)

#generate two histograms, 
# adding the second histogram to the first
hist(busTravel, col=myBlue)
hist(perTravel, col=myGreen, add=TRUE)

#add a legend
legend("topleft", c("Business", "Personal"), 
       fill=c(myBlue,myGreen ))

